@@ -1,29 +1,27 @@
 from logging import StreamHandler
+from jaaql.constants import ENVIRON__vault_key
 import re
 import logging
 import pkgutil
-from os.path import exists, join
+from os.path import exists
 import configparser
 from jaaql.openapi.swagger_documentation import produce_all_documentation
 from jaaql.utilities.options import *
 import sys
 import os
 import jaaql.documentation as documentation
-from jaaql.utilities.utils import get_jaaql_root
+from jaaql.utilities.utils import load_config
 from jaaql.mvc.controller import JAAQLController
 from jaaql.mvc.model import JAAQLModel
 from jaaql.mvc.controller_interface import JAAQLControllerInterface
 from jaaql.mvc.model_interface import JAAQLModelInterface
+from jaaql.config_constants import *
 
-DIR__config = "config"
-FILE__config = "config.ini"
-
-ENVIRON__vault_key = "JAAQL_VAULT_PASSWORD"
 
 DEFAULT__mfa_label = "test"
+
 CONFIG_KEY__security = "SECURITY"
 CONFIG_KEY_SECURITY__mfa_label = "mfa_label"
-CONFIG_KEY_SECURITY__use_mfa = "use_mfa"
 CONFIG_KEY_SECURITY__do_audit = "do_audit"
 CONFIG_KEY__swagger = "SWAGGER"
 CONFIG_KEY_SWAGGER__url = "url"
@@ -33,9 +31,6 @@ CONFIG_KEY_SERVER__port = "port"
 WARNING__vault_key_stdin = "MAJOR SECURITY ISSUE! Passing vault key via program arguments is insecure as other progra" \
                            "ms can see the arguments. Please provide via stdin instead!"
 
-WARNING__mfa_off = "MAJOR SECURITY ISSUE! config SECURITY->use_mfa is set to false. Please enable it for PROD (it wil" \
-                   "l be enabled using the default docker configuration"
-
 WARNING__audit_off = "Audit trail is off. Logs will still be kept by the internal postgres instance"
 
 
@@ -91,17 +86,7 @@ def create_app(is_gunicorn: bool = False, override_config_path: str = None, migr
 
     logging.getLogger("werkzeug").handlers.append(SensitiveHandler())
 
-    config_root = get_jaaql_root()
-    if is_gunicorn:
-        config_root = "/JAAQL-middleware-python/jaaql"
-
-    config = configparser.ConfigParser()
-    config.sections()
-    config_path = join(config_root, DIR__config, FILE__config)
-    if not exists(config_path):
-        raise Exception("Could not find config. Please check working directory has access to '" + config_path + "'")
-    config.read(config_path)
-    config = {s: dict(config.items(s)) for s in config.sections()}
+    config = load_config(is_gunicorn)
 
     if override_config_path is not None:
         override_config = configparser.ConfigParser()
@@ -124,12 +109,15 @@ def create_app(is_gunicorn: bool = False, override_config_path: str = None, migr
         print("MFA label is set to default. This isn't a security issue but adds a nice name when added to "
               "authenticator apps via QR codes. You can change in the config")
 
-    use_mfa = config[CONFIG_KEY__security][CONFIG_KEY_SECURITY__use_mfa] in ("true", "True", True)
+    force_mfa = config[CONFIG_KEY__security][CONFIG_KEY_SECURITY__force_mfa] in ("true", "True", True)
     do_audit = config[CONFIG_KEY__security][CONFIG_KEY_SECURITY__do_audit] in ("true", "True", True)
-    config[CONFIG_KEY__security][CONFIG_KEY_SECURITY__use_mfa] = use_mfa
+    invite_only = config[CONFIG_KEY__security][CONFIG_KEY_SECURITY__invite_only] in ("true", "True", True)
+
+    # The following code sets it "properly" in case it is accessed incorrectly from elsewhere
+    config[CONFIG_KEY__security][CONFIG_KEY_SECURITY__force_mfa] = force_mfa
     config[CONFIG_KEY__security][CONFIG_KEY_SECURITY__do_audit] = do_audit
-    if not use_mfa:
-        print(WARNING__mfa_off, file=sys.stderr)
+    config[CONFIG_KEY__security][CONFIG_KEY_SECURITY__invite_only] = invite_only
+
     if not do_audit:
         print(WARNING__audit_off, file=sys.stderr)
 
